import { defineComponent, ref } from 'vue'
import {
  ElPopover,
  ElScrollbar,
  ElCheckbox,
  ElCheckboxGroup,
  ElInput,
} from 'element-plus'
import { usableAllList } from '@/api/logistics'
const styles = {
  searchForm: {
    position: 'relative',
  },
  titleBox: {
    display: 'flex',
    padding: '10px',
    justifyContent: 'space-between',
    alignItems: 'center',
  },
  checkboxGroup: {
    display: 'flex',
    padding: '10px',
    justifyContent: 'space-between',
    backgroundColor: '#efefef',
  },
} as const
export default defineComponent({
  name: 'CustomizeForm',
  props: {
    modelValue: {
      type: Array as PropType<(string | number)[]>,
      default: () => [],
    },
  },
  emits: ['update:modelValue', 'validate'],
  setup() {
    const companySelectStatus = ref([])
    const companyList = ref([{ name: '1', items: [{ name: '1', id: '1' }] }])
    const selectedList = ref<(string | number)[]>([])
    const logisticsWayId = ref([])
    function setCheckAll() {}
    async function getAllList() {
      try {
        const res = await Promise.allSettled([usableAllList()])
        res.forEach(
          (
            item: PromiseSettledResult<{ code: number; data: never[] }>,
            index,
          ) => {
            if (item?.status === 'fulfilled') {
              if (item.value.code === 200) {
                if (index == 0) {
                  logisticsWayId.value = [...(item.value.data || [])]
                }
              }
            }
          },
        )
        console.log(59, logisticsWayId.value)
      } catch (error) {
        console.log(error)
      }
    }

    onMounted(() => {
      getAllList()
    })
    return () => (
      <ElPopover
        width="650px"
        placement="bottom-start"
        trigger="click"
        popper-style={{ padding: 0 }}
        v-slots={{
          reference: () => (
            <ElInput style={{ width: '100%' }} placeholder="请选择物流方式" />
          ),
        }}
      >
        <ElScrollbar class="scroll-container" maxHeight="450px">
          {companyList.value.map((company, index) => (
            <div class="companyBox" key={index}>
              <div style={styles.titleBox}>
                <div class="title">{company.name}</div>
                <ElCheckbox
                  modelValue={companySelectStatus.value[index]}
                  onChange={() => setCheckAll()}
                  class="selectAll"
                >
                  全选
                </ElCheckbox>
              </div>

              <ElCheckboxGroup
                modelValue={selectedList.value}
                onUpdate:modelValue={(value) => (selectedList.value = value)}
                style={styles.checkboxGroup}
              >
                {company.items.map((item) => (
                  <ElCheckbox
                    label={item.name}
                    value={item.id}
                    key={`item-${item.id}`}
                    class="checkboxItem"
                  />
                ))}
              </ElCheckboxGroup>
            </div>
          ))}
        </ElScrollbar>
      </ElPopover>
    )
  },
})
